summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:00 -0600
commit6ade7e598a18691f3f92471c4441d856b3ac54dc (patch)
treeca18ed733e273279bab574978806068e506c241a
parent5e3fc3a36b58c4e1cb48e31a350f76b7a81b3170 (diff)
downloadtqscintilla-6ade7e59.tar.gz
tqscintilla-6ade7e59.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 5e3fc3a36b58c4e1cb48e31a350f76b7a81b3170.
-rw-r--r--ChangeLog4
-rwxr-xr-xdoc/Scintilla/ScintillaDoc.html16
-rwxr-xr-xdoc/Scintilla/ScintillaHistory.html18
-rw-r--r--doc/html/classQextScintilla-members.html4
-rw-r--r--doc/html/classQextScintilla.html8
-rw-r--r--doc/html/classQextScintillaBase-members.html2
-rw-r--r--doc/html/classQextScintillaBase.html6
-rw-r--r--doc/html/classQextScintillaPrinter.html2
-rw-r--r--doc/html/functions_0x73.html2
-rw-r--r--doc/html/functions_func_0x73.html2
-rw-r--r--example/application.cpp6
-rwxr-xr-xinclude/Platform.h4
-rwxr-xr-xinclude/Scintilla.h2
-rwxr-xr-xinclude/Scintilla.iface12
-rw-r--r--qt/PlatQt.cpp14
-rw-r--r--qt/SciListBox.cpp4
-rw-r--r--qt/ScintillaQt.cpp10
-rw-r--r--qt/qextscintilla.cpp10
-rw-r--r--qt/qextscintilla.h4
-rw-r--r--qt/qextscintillabase.cpp26
-rw-r--r--qt/qextscintillabase.h2
-rw-r--r--qt/qextscintillalexer.cpp8
-rw-r--r--qt/qextscintillalexercss.cpp6
-rw-r--r--qt/qextscintillalexerhtml.cpp2
-rw-r--r--qt/qextscintillalexeridl.cpp2
-rw-r--r--qt/qextscintillalexertex.cpp2
-rw-r--r--qt/qextscintillaprinter.h2
-rwxr-xr-xsrc/AutoComplete.cpp4
-rwxr-xr-xsrc/AutoComplete.h2
-rwxr-xr-xsrc/CallTip.cpp2
-rwxr-xr-xsrc/CallTip.h2
-rwxr-xr-xsrc/Editor.cpp22
-rwxr-xr-xsrc/Editor.h2
-rwxr-xr-xsrc/LineMarker.cpp2
34 files changed, 108 insertions, 108 deletions
diff --git a/ChangeLog b/ChangeLog
index d09cbfd..faa8354 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -96,7 +96,7 @@ Possibly fixed a possible problem with double clicking under Windows.
2006/07/02 14:27:26 phil
Added setWrapVisualFlags(), WrapMode::WrapCharacter, WrapVisualFlag to
QextScintilla.
-The layout cache is now set according to the wrap mode.
+The tqlayout cache is now set according to the wrap mode.
Setting a wrap mode now disables the horizontal scrollbar.
@@ -840,7 +840,7 @@ Fixed the QextScintilla::marginClicked() signature and changed it to pass the
line number rather than the pixel position.
Added mouse wheel support from Detlev.
Setting the lexer no longer resets all the styles.
-The cursor shape now changes when moved across the text area and margins.
+The cursor tqshape now changes when moved across the text area and margins.
Added ensureLineVisible(), setMarginsBackgroundColor(),
setMarginsForegroundColor(), setMarginsFont() and the overloaded
setMarginWidth() to QextScintilla.
diff --git a/doc/Scintilla/ScintillaDoc.html b/doc/Scintilla/ScintillaDoc.html
index a32f9ef..4d0b584 100755
--- a/doc/Scintilla/ScintillaDoc.html
+++ b/doc/Scintilla/ScintillaDoc.html
@@ -473,7 +473,7 @@
<a class="message" href="#SCI_GETSTYLEBITSNEEDED">SCI_GETSTYLEBITSNEEDED</a>.</p>
<p><b id="TextRange">TextRange</b> and <b id="CharacterRange">CharacterRange</b><br />
- These structures are defined to be exactly the same shape as the Win32 <code>TEXTRANGE</code>
+ These structures are defined to be exactly the same tqshape as the Win32 <code>TEXTRANGE</code>
and <code>CHARRANGE</code>, so that older code that treats Scintilla as a RichEdit will
work.</p>
<pre>
@@ -677,7 +677,7 @@ struct TextRange {
href="#SCI_SEARCHINTARGET">SCI_SEARCHINTARGET</a></code></p>
<p><b id="TextToFind">TextToFind</b><br />
- This structure is defined to have exactly the same shape as the Win32 structure
+ This structure is defined to have exactly the same tqshape as the Win32 structure
<code>FINDTEXTEX</code> for old code that treated Scintilla as a RichEdit control.</p>
<pre>
struct TextToFind {
@@ -2873,7 +2873,7 @@ struct TextToFind {
style information (for 32 styles) and 3 bits of indicator information for 3 independent
indicators so that, for example, syntax errors, deprecated names and bad indentation could all
be displayed at once. Indicators may be displayed as simple underlines, squiggly underlines, a
- line of small 'T' shapes, a line of diagonal hatching, a strike-out or a rectangle around the text.</p>
+ line of small 'T' tqshapes, a line of diagonal hatching, a strike-out or a rectangle around the text.</p>
<p>The indicators are set using <a class="message"
href="#SCI_STARTSTYLING"><code>SCI_STARTSTYLING</code></a> with a <code>INDICS_MASK</code> mask
@@ -2886,7 +2886,7 @@ struct TextToFind {
Use <a class="message" href="#SCI_GETENDSTYLED"><code>SCI_GETENDSTYLED</code></a>
to retrieve the current "styled to" position and
<a class="message" href="#SCI_STARTSTYLING"><code>SCI_STARTSTYLING</code></a>
- to reset the styling position and mask (<code>0x1f </code> in the default layout of 5 style bits and 3 indicator bits)
+ to reset the styling position and mask (<code>0x1f </code> in the default tqlayout of 5 style bits and 3 indicator bits)
when you are done.</p>
<p>The number of bits used for styles can be altered with <a class="message"
@@ -2947,7 +2947,7 @@ struct TextToFind {
<td align="center">2</td>
- <td>A line of small T shapes.</td>
+ <td>A line of small T tqshapes.</td>
</tr>
<tr>
@@ -4110,10 +4110,10 @@ sptr_t CallScintilla(unsigned int iMessage, uptr_t wParam, sptr_t lParam){
Independent from drawing a visual flag at the begin the subline can have an indention.</p>
<p>Much of the time used by Scintilla is spent on laying out and drawing text. The same text
- layout calculations may be performed many times even when the data used in these calculations
- does not change. To avoid these unnecessary calculations in some circumstances, the line layout
+ tqlayout calculations may be performed many times even when the data used in these calculations
+ does not change. To avoid these unnecessary calculations in some circumstances, the line tqlayout
cache can store the results of the calculations. The cache is invalidated whenever the
- underlying data, such as the contents or styling of the document changes. Caching the layout of
+ underlying data, such as the contents or styling of the document changes. Caching the tqlayout of
the whole document has the most effect, making dynamic line wrap as much as 20 times faster but
this requires 7 times the memory required by the document contents plus around 80 bytes per
line.</p>
diff --git a/doc/Scintilla/ScintillaHistory.html b/doc/Scintilla/ScintillaHistory.html
index 94a7984..a4a74d6 100755
--- a/doc/Scintilla/ScintillaHistory.html
+++ b/doc/Scintilla/ScintillaHistory.html
@@ -578,7 +578,7 @@
Empty ranges can no longer be dragged.
</li>
<li>
- Crash fixed when calls made that use layout inside the painted notification.
+ Crash fixed when calls made that use tqlayout inside the painted notification.
</li>
<li>
Bug fixed where Scintilla created pixmap buffers that were too large leading
@@ -595,8 +595,8 @@
SciTE HTML exporter no longer honours monospaced font setting.
</li>
<li>
- Line layout cache in page mode caches the line of the caret. An assertion is
- now used to ensure that the layout reentrancy problem that caused this
+ Line tqlayout cache in page mode caches the line of the caret. An assertion is
+ now used to ensure that the tqlayout reentrancy problem that caused this
is easier to find.
</li>
<li>
@@ -1285,7 +1285,7 @@
Bug fixed where SCI_LINEENDWRAP would move too far when line ends are visible.
</li>
<li>
- Bugs fixed where calltips with unicode or other non-ASCII text would display
+ Bugs fixed where calltips with tqunicode or other non-ASCII text would display
incorrectly.
</li>
<li>
@@ -1533,7 +1533,7 @@
Bug in SciTE on Windows fixed where clipboard commands stopped working.
</li>
<li>
- Crashing bugs in display fixed in line layout cache.
+ Crashing bugs in display fixed in line tqlayout cache.
</li>
<li>
Crashing bug may be fixed on AMD64 processor on GTK+.
@@ -2954,7 +2954,7 @@
Released on 15 March 2002.
</li>
<li>
- Line layout cache implemented to improve performance by maintaining
+ Line tqlayout cache implemented to improve performance by maintaining
the positioning of characters on lines. Can be set to cache nothing,
the line with the caret, the visible page or the whole document.
</li>
@@ -4592,7 +4592,7 @@
Tool bar.
</li>
<li>
- Status bar now on Windows as well as GTK+.
+ tqStatus bar now on Windows as well as GTK+.
</li>
<li>
Input fields in Find and Replace dialogs now have history on both Windows and
@@ -4795,7 +4795,7 @@
Caret policy determines how closely caret is tracked by visible area.
</li>
<li>
- New marker shapes: arrow pointing down, plus and minus.
+ New marker tqshapes: arrow pointing down, plus and minus.
</li>
<li>
Optionally display full path in title rather than just file name.
@@ -4879,7 +4879,7 @@
Borland compatible makefile.
</li>
<li>
- Status bar showing caret position in GTK+ version of SciTE.
+ tqStatus bar showing caret position in GTK+ version of SciTE.
</li>
<li>
Bug fixes to selection drawing when part of selection outside window, mouse release over
diff --git a/doc/html/classQextScintilla-members.html b/doc/html/classQextScintilla-members.html
index 90ed520..50240f1 100644
--- a/doc/html/classQextScintilla-members.html
+++ b/doc/html/classQextScintilla-members.html
@@ -98,7 +98,7 @@
<tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#85e6877f9aad613a869fe5b7d97f9035">focusInEvent</a>(TQFocusEvent *)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [protected, virtual]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#9516bc2125ea51a8de4c21f6af42a4b1">focusNextPrevChild</a>(bool)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [protected, virtual]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#f87a97050d71a323d47d666fe4a5547b">focusOutEvent</a>(TQFocusEvent *)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [protected, virtual]</code></td></tr>
- <tr class="memlist"><td><a class="el" href="classQextScintilla.html#5b289640689062f4fa5479c7212107c0">foldAll</a>(bool children=FALSE)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [virtual, slot]</code></td></tr>
+ <tr class="memlist"><td><a class="el" href="classQextScintilla.html#5b289640689062f4fa5479c7212107c0">foldAll</a>(bool tqchildren=FALSE)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [virtual, slot]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#86418f82fe35ff366f4ef023c470f0a1">folding</a>() const </td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [inline]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#f81c922d74d8746d9cbc8d576c440dd4">foldLine</a>(int line)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [virtual, slot]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#34af4ea7604b156b69f31b5412db93cf">FoldStyle</a> enum name</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td></td></tr>
@@ -956,7 +956,7 @@
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#945affc0b0f8f25f58138f923d5a270d">setWrapMode</a>(WrapMode mode)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [virtual, slot]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#11ef30c49b7c6fb96988a94059efa687">setWrapVisualFlags</a>(WrapVisualFlag eflag, WrapVisualFlag sflag=WrapFlagNone, int sindent=0)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#74a4da1e86eda7f62262cea8a4a9b26a">showUserList</a>(int id, const TQStringList &amp;list)</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td></td></tr>
- <tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">sizeHint</a>() const </td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [virtual]</code></td></tr>
+ <tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">tqsizeHint</a>() const </td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [virtual]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#c9490bc31746441fa4f228f44679b06b0663484a90fdee0162e2e2e267c2da8a">SloppyBraceMatch</a> enum value</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#1cefba8e6020a5b760511f83aa4ca72ee7978b23c827aa996489af72541c670a">SmallRectangle</a> enum value</td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintilla.html#ea83bb0bc19af4a776b68ee3eda10c61">standardCommands</a>() const </td><td><a class="el" href="classQextScintilla.html">QextScintilla</a></td><td><code> [inline]</code></td></tr>
diff --git a/doc/html/classQextScintilla.html b/doc/html/classQextScintilla.html
index 1bca3d7..04c98c8 100644
--- a/doc/html/classQextScintilla.html
+++ b/doc/html/classQextScintilla.html
@@ -172,7 +172,7 @@ Inherits <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>.
<li>virtual void <a class="el" href="classQextScintilla.html#d5d5178610285dda5004ccc5c5c6c306">cut</a> ()
<li>virtual void <a class="el" href="classQextScintilla.html#dd5100eebb1241b90da9b77cfca26c8d">ensureCursorVisible</a> ()
<li>virtual void <a class="el" href="classQextScintilla.html#8c5a39688b5ca5995f8060941a8065d4">ensureLineVisible</a> (int line)
-<li>virtual void <a class="el" href="classQextScintilla.html#5b289640689062f4fa5479c7212107c0">foldAll</a> (bool children=FALSE)
+<li>virtual void <a class="el" href="classQextScintilla.html#5b289640689062f4fa5479c7212107c0">foldAll</a> (bool tqchildren=FALSE)
<li>virtual void <a class="el" href="classQextScintilla.html#f81c922d74d8746d9cbc8d576c440dd4">foldLine</a> (int line)
<li>virtual void <a class="el" href="classQextScintilla.html#0017b86a4fff9d1228b204deda1e9d57">indent</a> (int line)
<li>virtual void <a class="el" href="classQextScintilla.html#bd158556a8565eb1bf92f2dd8fa9b66f">insert</a> (const TQString &amp;text)
@@ -3231,7 +3231,7 @@ Ensures that the line number <em>line</em> is visible.
</div>
</div><p>
-<a class="anchor" name="5b289640689062f4fa5479c7212107c0"></a><!-- doxytag: member="QextScintilla::foldAll" ref="5b289640689062f4fa5479c7212107c0" args="(bool children=FALSE)" -->
+<a class="anchor" name="5b289640689062f4fa5479c7212107c0"></a><!-- doxytag: member="QextScintilla::foldAll" ref="5b289640689062f4fa5479c7212107c0" args="(bool tqchildren=FALSE)" -->
<div class="memitem">
<div class="memproto">
<table class="memname">
@@ -3239,7 +3239,7 @@ Ensures that the line number <em>line</em> is visible.
<td class="memname">virtual void QextScintilla::foldAll </td>
<td>(</td>
<td class="paramtype">bool&nbsp;</td>
- <td class="paramname"> <em>children</em> = <code>FALSE</code> </td>
+ <td class="paramname"> <em>tqchildren</em> = <code>FALSE</code> </td>
<td>&nbsp;)&nbsp;</td>
<td width="100%"><code> [virtual, slot]</code></td>
</tr>
@@ -3248,7 +3248,7 @@ Ensures that the line number <em>line</em> is visible.
<div class="memdoc">
<p>
-If any lines are currently folded then they are all unfolded. Otherwise all lines are folded. This has the same effect as clicking in the fold margin with the shift and control keys pressed. If <em>children</em> is not set (the default) then only the top level fold points are affected, otherwise the state of all fold points are changed.
+If any lines are currently folded then they are all unfolded. Otherwise all lines are folded. This has the same effect as clicking in the fold margin with the shift and control keys pressed. If <em>tqchildren</em> is not set (the default) then only the top level fold points are affected, otherwise the state of all fold points are changed.
</div>
</div><p>
<a class="anchor" name="f81c922d74d8746d9cbc8d576c440dd4"></a><!-- doxytag: member="QextScintilla::foldLine" ref="f81c922d74d8746d9cbc8d576c440dd4" args="(int line)" -->
diff --git a/doc/html/classQextScintillaBase-members.html b/doc/html/classQextScintillaBase-members.html
index 4983d70..2a37d2f 100644
--- a/doc/html/classQextScintillaBase-members.html
+++ b/doc/html/classQextScintillaBase-members.html
@@ -747,7 +747,7 @@
<tr bgcolor="#f0f0f0"><td><b>SendScintilla</b>(unsigned int msg, const TQColor &amp;col) (defined in <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td></td></tr>
<tr bgcolor="#f0f0f0"><td><b>SendScintilla</b>(unsigned int msg, unsigned long wParam, TQPainter *hdc, const TQRect &amp;rc, long cpMin, long cpMax) (defined in <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td></td></tr>
<tr bgcolor="#f0f0f0"><td><b>SendScintilla</b>(unsigned int msg, unsigned long wParam, const TQPixmap *lParam) (defined in <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [inline]</code></td></tr>
- <tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">sizeHint</a>() const </td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [virtual]</code></td></tr>
+ <tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">tqsizeHint</a>() const </td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [virtual]</code></td></tr>
<tr class="memlist"><td><a class="el" href="classQextScintillaBase.html#7c1be000329c8f9e328999cbc03ba9a7">startDrag</a>()</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td><code> [protected, virtual]</code></td></tr>
<tr bgcolor="#f0f0f0"><td><b>STYLE_BRACEBAD</b> enum value (defined in <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td></td></tr>
<tr bgcolor="#f0f0f0"><td><b>STYLE_BRACELIGHT</b> enum value (defined in <a class="el" href="classQextScintillaBase.html">QextScintillaBase</a>)</td><td><a class="el" href="classQextScintillaBase.html">QextScintillaBase</a></td><td></td></tr>
diff --git a/doc/html/classQextScintillaBase.html b/doc/html/classQextScintillaBase.html
index d6e700d..0efb8d3 100644
--- a/doc/html/classQextScintillaBase.html
+++ b/doc/html/classQextScintillaBase.html
@@ -2306,7 +2306,7 @@ long <b>SendScintilla</b> (unsigned int msg, const TQColor &amp;col)
long <b>SendScintilla</b> (unsigned int msg, unsigned long wParam, TQPainter *hdc, const TQRect &amp;rc, long cpMin, long cpMax)
<li><a class="anchor" name="10a88dc5c6aa9d423eeea62b21843264"></a><!-- doxytag: member="QextScintillaBase::SendScintilla" ref="10a88dc5c6aa9d423eeea62b21843264" args="(unsigned int msg, unsigned long wParam, const TQPixmap *lParam)" -->
long <b>SendScintilla</b> (unsigned int msg, unsigned long wParam, const TQPixmap *lParam)
-<li>virtual TQSize <a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">sizeHint</a> () const
+<li>virtual TQSize <a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">tqsizeHint</a> () const
<li>TQWidget * <a class="el" href="classQextScintillaBase.html#7c7723d64865b462ecfbf4152d836cae">viewport</a> () const
</ul>
<h2>Static Public Member Functions</h2>
@@ -2938,12 +2938,12 @@ Returns a pointer to a <a class="el" href="classQextScintillaBase.html">QextScin
Send the Scintilla message <em>msg</em> with the optional parameters <em>wParam</em> and <em>lParam</em>.
</div>
</div><p>
-<a class="anchor" name="171ce27ddcfabf024cc5539181f253dd"></a><!-- doxytag: member="QextScintillaBase::sizeHint" ref="171ce27ddcfabf024cc5539181f253dd" args="() const " -->
+<a class="anchor" name="171ce27ddcfabf024cc5539181f253dd"></a><!-- doxytag: member="QextScintillaBase::tqsizeHint" ref="171ce27ddcfabf024cc5539181f253dd" args="() const " -->
<div class="memitem">
<div class="memproto">
<table class="memname">
<tr>
- <td class="memname">virtual TQSize QextScintillaBase::sizeHint </td>
+ <td class="memname">virtual TQSize QextScintillaBase::tqsizeHint </td>
<td>(</td>
<td class="paramname"> </td>
<td>&nbsp;)&nbsp;</td>
diff --git a/doc/html/classQextScintillaPrinter.html b/doc/html/classQextScintillaPrinter.html
index a53693e..8ed8223 100644
--- a/doc/html/classQextScintillaPrinter.html
+++ b/doc/html/classQextScintillaPrinter.html
@@ -36,7 +36,7 @@
<hr><a name="_details"></a><h2>Detailed Description</h2>
The <a class="el" href="classQextScintillaPrinter.html">QextScintillaPrinter</a> class is a sub-class of the TQt TQPrinter class that is able to print the text of a Scintilla document.
<p>
-The class can be further sub-classed to alter to layout of the text, adding headers and footers for example.
+The class can be further sub-classed to alter to tqlayout of the text, adding headers and footers for example.
<p>
<hr><h2>Constructor &amp; Destructor Documentation</h2>
<a class="anchor" name="d304f2d535a10595acc613521f92dc49"></a><!-- doxytag: member="QextScintillaPrinter::QextScintillaPrinter" ref="d304f2d535a10595acc613521f92dc49" args="(PrinterMode mode=ScreenResolution)" -->
diff --git a/doc/html/functions_0x73.html b/doc/html/functions_0x73.html
index 1960d09..9e1937a 100644
--- a/doc/html/functions_0x73.html
+++ b/doc/html/functions_0x73.html
@@ -334,7 +334,7 @@ Here is a list of all documented class members with links to the class documenta
: <a class="el" href="classQextScintillaLexerHTML.html#fa7eeca9e9d6989991ea3dc3386fb8c261be7257f0b33af5eebee59e5daefdff">QextScintillaLexerHTML</a><li>showUserList()
: <a class="el" href="classQextScintilla.html#74a4da1e86eda7f62262cea8a4a9b26a">QextScintilla</a><li>SingleQuotedHereDocument
: <a class="el" href="classQextScintillaLexerPerl.html#3adbc396a8aceddb3e327505860b1fbdb84f237d13384cb47bcf579f29a77eab">QextScintillaLexerPerl</a>, <a class="el" href="classQextScintillaLexerBash.html#a161d468183d486788d727114d801f11ed5c6c7c814c87b3995bc1d0e129cdf6">QextScintillaLexerBash</a><li>SingleQuotedString
-: <a class="el" href="classQextScintillaLexerSQL.html#31e2976a0e42d9f90cdfe7aafd4264935022b23b5cbb05e3edfa0c9d49f866a4">QextScintillaLexerSQL</a>, <a class="el" href="classQextScintillaLexerRuby.html#c12d2ddff5d8652b10066ef4ab5df6733d453fb290fba122980aa29757cc7839">QextScintillaLexerRuby</a>, <a class="el" href="classQextScintillaLexerPython.html#99004ac9e2112951a73f2dfc7724a5a7f299751dbcf5d3dc7645fbb54a89cdc3">QextScintillaLexerPython</a>, <a class="el" href="classQextScintillaLexerPerl.html#3adbc396a8aceddb3e327505860b1fbd7b9ff96a73c4d75e880eb0977e18a24f">QextScintillaLexerPerl</a>, <a class="el" href="classQextScintillaLexerCSS.html#c8ee4747b06e3739126a3ae64f9cb46e4a6cf494de949384a8205d4dc6f320f3">QextScintillaLexerCSS</a>, <a class="el" href="classQextScintillaLexerCPP.html#542bd72841348de065bad4c9d8a39e51f7648858efb30abf136bf9f82a516296">QextScintillaLexerCPP</a>, <a class="el" href="classQextScintillaLexerBash.html#a161d468183d486788d727114d801f1177f2cc65d0990de81d205c6672206da0">QextScintillaLexerBash</a><li>sizeHint()
+: <a class="el" href="classQextScintillaLexerSQL.html#31e2976a0e42d9f90cdfe7aafd4264935022b23b5cbb05e3edfa0c9d49f866a4">QextScintillaLexerSQL</a>, <a class="el" href="classQextScintillaLexerRuby.html#c12d2ddff5d8652b10066ef4ab5df6733d453fb290fba122980aa29757cc7839">QextScintillaLexerRuby</a>, <a class="el" href="classQextScintillaLexerPython.html#99004ac9e2112951a73f2dfc7724a5a7f299751dbcf5d3dc7645fbb54a89cdc3">QextScintillaLexerPython</a>, <a class="el" href="classQextScintillaLexerPerl.html#3adbc396a8aceddb3e327505860b1fbd7b9ff96a73c4d75e880eb0977e18a24f">QextScintillaLexerPerl</a>, <a class="el" href="classQextScintillaLexerCSS.html#c8ee4747b06e3739126a3ae64f9cb46e4a6cf494de949384a8205d4dc6f320f3">QextScintillaLexerCSS</a>, <a class="el" href="classQextScintillaLexerCPP.html#542bd72841348de065bad4c9d8a39e51f7648858efb30abf136bf9f82a516296">QextScintillaLexerCPP</a>, <a class="el" href="classQextScintillaLexerBash.html#a161d468183d486788d727114d801f1177f2cc65d0990de81d205c6672206da0">QextScintillaLexerBash</a><li>tqsizeHint()
: <a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">QextScintillaBase</a><li>SloppyBraceMatch
: <a class="el" href="classQextScintilla.html#c9490bc31746441fa4f228f44679b06b0663484a90fdee0162e2e2e267c2da8a">QextScintilla</a><li>SmallRectangle
: <a class="el" href="classQextScintilla.html#1cefba8e6020a5b760511f83aa4ca72ee7978b23c827aa996489af72541c670a">QextScintilla</a><li>Spaces
diff --git a/doc/html/functions_func_0x73.html b/doc/html/functions_func_0x73.html
index 1190596..77b5034 100644
--- a/doc/html/functions_func_0x73.html
+++ b/doc/html/functions_func_0x73.html
@@ -159,7 +159,7 @@
: <a class="el" href="classQextScintilla.html#811888818870dd0d9cd74d297f711bc8">QextScintilla</a><li>setWrapMode()
: <a class="el" href="classQextScintillaPrinter.html#f4904d6ba001f4c7145983f9814f00c1">QextScintillaPrinter</a>, <a class="el" href="classQextScintilla.html#945affc0b0f8f25f58138f923d5a270d">QextScintilla</a><li>setWrapVisualFlags()
: <a class="el" href="classQextScintilla.html#11ef30c49b7c6fb96988a94059efa687">QextScintilla</a><li>showUserList()
-: <a class="el" href="classQextScintilla.html#74a4da1e86eda7f62262cea8a4a9b26a">QextScintilla</a><li>sizeHint()
+: <a class="el" href="classQextScintilla.html#74a4da1e86eda7f62262cea8a4a9b26a">QextScintilla</a><li>tqsizeHint()
: <a class="el" href="classQextScintillaBase.html#171ce27ddcfabf024cc5539181f253dd">QextScintillaBase</a><li>standardCommands()
: <a class="el" href="classQextScintilla.html#ea83bb0bc19af4a776b68ee3eda10c61">QextScintilla</a><li>startDrag()
: <a class="el" href="classQextScintillaBase.html#7c1be000329c8f9e328999cbc03ba9a7">QextScintillaBase</a><li>startRecording()
diff --git a/example/application.cpp b/example/application.cpp
index bf19fb6..fbc03be 100644
--- a/example/application.cpp
+++ b/example/application.cpp
@@ -23,7 +23,7 @@
#include <tqprinter.h>
#include <tqapplication.h>
#include <tqaccel.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqpainter.h>
#include <tqpaintdevicemetrics.h>
#include <tqwhatsthis.h>
@@ -185,7 +185,7 @@ void ApplicationWindow::save()
TQString text = e->text();
TQFile f( filename );
if ( !f.open( IO_WriteOnly ) ) {
- statusBar()->message( TQString("Could not write to %1").arg(filename),
+ statusBar()->message( TQString("Could not write to %1").tqarg(filename),
2000 );
return;
}
@@ -198,7 +198,7 @@ void ApplicationWindow::save()
setCaption( filename );
- statusBar()->message( TQString( "File %1 saved" ).arg( filename ), 2000 );
+ statusBar()->message( TQString( "File %1 saved" ).tqarg( filename ), 2000 );
}
diff --git a/include/Platform.h b/include/Platform.h
index 33245b9..3cc849b 100755
--- a/include/Platform.h
+++ b/include/Platform.h
@@ -354,7 +354,7 @@ public:
virtual void SetClip(PRectangle rc)=0;
virtual void FlushCachedState()=0;
- virtual void SetUnicodeMode(bool unicodeMode_)=0;
+ virtual void SetUnicodeMode(bool tqunicodeMode_)=0;
virtual void SetDBCSMode(int codePage)=0;
#if defined(PLAT_QT)
@@ -412,7 +412,7 @@ public:
static ListBox *Allocate();
virtual void SetFont(Font &font)=0;
- virtual void Create(Window &parent, int ctrlID, Point location, int lineHeight_, bool unicodeMode_)=0;
+ virtual void Create(Window &parent, int ctrlID, Point location, int lineHeight_, bool tqunicodeMode_)=0;
virtual void SetAverageCharWidth(int width)=0;
virtual void SetVisibleRows(int rows)=0;
virtual int GetVisibleRows() const=0;
diff --git a/include/Scintilla.h b/include/Scintilla.h
index ffb1ffa..326831d 100755
--- a/include/Scintilla.h
+++ b/include/Scintilla.h
@@ -696,7 +696,7 @@ typedef sptr_t (*SciFnDirect)(sptr_t ptr, unsigned int iMessage, uptr_t wParam,
#define SCN_AUTOCSELECTION 2022
//--Autogenerated -- end of section automatically generated from Scintilla.iface
-// These structures are defined to be exactly the same shape as the Win32
+// These structures are defined to be exactly the same tqshape as the Win32
// CHARRANGE, TEXTRANGE, FINDTEXTEX, FORMATRANGE, and NMHDR structs.
// So older code that treats Scintilla as a RichEdit will work.
diff --git a/include/Scintilla.iface b/include/Scintilla.iface
index c3e5b56..6154ca5 100755
--- a/include/Scintilla.iface
+++ b/include/Scintilla.iface
@@ -977,7 +977,7 @@ fun void HideLines=2227(int lineStart, int lineEnd)
# Is a line visible?
get bool GetLineVisible=2228(int line,)
-# Show the children of a header line.
+# Show the tqchildren of a header line.
set void SetFoldExpanded=2229(int line, bool expanded)
# Is a header line expanded?
@@ -1075,10 +1075,10 @@ val SC_CACHE_CARET=1
val SC_CACHE_PAGE=2
val SC_CACHE_DOCUMENT=3
-# Sets the degree of caching of layout information.
+# Sets the degree of caching of tqlayout information.
set void SetLayoutCache=2272(int mode,)
-# Retrieve the degree of caching of layout information.
+# Retrieve the degree of caching of tqlayout information.
get int GetLayoutCache=2273(,)
# Sets the document width assumed for scrolling.
@@ -1407,16 +1407,16 @@ set void SetFocus=2380(bool focus,)
get bool GetFocus=2381(,)
# Change error status - 0 = OK.
-set void SetStatus=2382(int statusCode,)
+set void SettqStatus=2382(int statusCode,)
# Get error status.
-get int GetStatus=2383(,)
+get int GettqStatus=2383(,)
# Set whether the mouse is captured when its button is pressed.
set void SetMouseDownCaptures=2384(bool captures,)
# Get whether mouse gets captured.
get bool GetMouseDownCaptures=2385(,)
-enu CursorShape=SC_CURSOR
+enu tqCursorShape=SC_CURSOR
val SC_CURSORNORMAL=-1
val SC_CURSORWAIT=4
# Sets the cursor to one of the SC_CURSOR* values.
diff --git a/qt/PlatQt.cpp b/qt/PlatQt.cpp
index 3b563c6..db5e94a 100644
--- a/qt/PlatQt.cpp
+++ b/qt/PlatQt.cpp
@@ -194,7 +194,7 @@ public:
void SetClip(PRectangle rc);
void FlushCachedState() {painter -> flush();}
- void SetUnicodeMode(bool unicodeMode_) {unicodeMode = unicodeMode_;}
+ void SetUnicodeMode(bool tqunicodeMode_) {tqunicodeMode = tqunicodeMode_;}
void SetDBCSMode(int codePage) {}
void DrawXPM(PRectangle rc,const XPM *xpm);
@@ -207,7 +207,7 @@ private:
static TQColor convertTQColor(const ColourAllocated &col,
unsigned alpha = 0xff);
- bool unicodeMode;
+ bool tqunicodeMode;
bool mypainter;
TQPainter *painter;
};
@@ -217,7 +217,7 @@ Surface *Surface::Allocate()
return new SurfaceImpl;
}
-SurfaceImpl::SurfaceImpl() : unicodeMode(false), mypainter(false), painter(0)
+SurfaceImpl::SurfaceImpl() : tqunicodeMode(false), mypainter(false), painter(0)
{
}
@@ -448,7 +448,7 @@ void SurfaceImpl::MeasureWidths(Font &font_,const char *s,int len,
{
totalWidth += fm.width(qs[i]);
- int l = (unicodeMode ? TQString(qs[i]).utf8().length() : 1);
+ int l = (tqunicodeMode ? TQString(qs[i]).utf8().length() : 1);
while (l--)
positions[ui++] = totalWidth;
@@ -533,7 +533,7 @@ bool SurfaceImpl::setFont(Font &font_)
// Convert a Scintilla string to a TQt Unicode string.
TQString SurfaceImpl::convertText(const char *s,int len)
{
- if (unicodeMode)
+ if (tqunicodeMode)
return TQString::fromUtf8(s,len);
TQString qs;
@@ -594,7 +594,7 @@ PRectangle Window::GetPosition()
if (w)
{
- const TQRect &r = w -> geometry();
+ const TQRect &r = w -> tqgeometry();
rc.left = r.left();
rc.top = r.top();
@@ -661,7 +661,7 @@ void Window::SetFont(Font &font)
void Window::SetCursor(Cursor curs)
{
- TQt::CursorShape qc;
+ TQt::tqCursorShape qc;
switch (curs)
{
diff --git a/qt/ScintillaQt.cpp b/qt/ScintillaQt.cpp
index e626d17..322f300 100644
--- a/qt/ScintillaQt.cpp
+++ b/qt/ScintillaQt.cpp
@@ -25,7 +25,7 @@
#include <tqpopupmenu.h>
#include <tqstring.h>
#include <tqtimer.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqdragobject.h>
#include <tqpainter.h>
@@ -446,7 +446,7 @@ TQString ScintillaTQt::textRange(const SelectionText *text)
// Copy the selected text to the clipboard.
void ScintillaTQt::CopyToClipboard(const SelectionText &selectedText)
{
- TQApplication::clipboard() -> setText(textRange(&selectedText));
+ TQApplication::tqclipboard() -> setText(textRange(&selectedText));
}
@@ -466,7 +466,7 @@ void ScintillaTQt::Copy()
// Implement paste.
void ScintillaTQt::Paste()
{
- TQString str = TQApplication::clipboard() -> text();
+ TQString str = TQApplication::tqclipboard() -> text();
if (str.isEmpty())
return;
@@ -607,7 +607,7 @@ void ScintillaTQt::ClaimSelection()
if (isSel)
{
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
// If we support X11 style selection then make it available
// now.
@@ -683,7 +683,7 @@ void ScintillaTQt::paintEvent(TQPaintEvent *pe)
delete sw;
// If the painting area was insufficient to cover the new style
- // or brace highlight positions then repaint the whole thing.
+ // or brace highlight positions then tqrepaint the whole thing.
if (paintState == paintAbandoned)
PWindow(wMain) -> update();
}
diff --git a/qt/qextscintillabase.cpp b/qt/qextscintillabase.cpp
index 4279094..aa58b9e 100644
--- a/qt/qextscintillabase.cpp
+++ b/qt/qextscintillabase.cpp
@@ -21,9 +21,9 @@
#include <tqapplication.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqscrollbar.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcolor.h>
#include <tqevent.h>
#include <tqdragobject.h>
@@ -70,22 +70,22 @@ QextScintillaBase::QextScintillaBase(TQWidget *parent,const char *name,WFlags f)
{
sci = 0;
- TQGridLayout *layout = new TQGridLayout(this,2,2);
+ TQGridLayout *tqlayout = new TQGridLayout(this,2,2);
txtarea = new TQWidget(this,0,WRepaintNoErase|WResizeNoErase);
- txtarea -> setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Expanding));
+ txtarea -> tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Expanding));
txtarea -> setMouseTracking(TRUE);
txtarea -> setAcceptDrops(TRUE);
txtarea -> setFocusPolicy(WheelFocus);
txtarea -> setFocusProxy(this);
- layout -> addWidget(txtarea,0,0);
+ tqlayout -> addWidget(txtarea,0,0);
vsb = new TQScrollBar(Qt::Vertical,this);
- layout -> addWidget(vsb,0,1);
+ tqlayout -> addWidget(vsb,0,1);
connect(vsb,TQT_SIGNAL(valueChanged(int)),TQT_SLOT(handleVSb(int)));
hsb = new TQScrollBar(Qt::Horizontal,this);
- layout -> addWidget(hsb,1,0);
+ tqlayout -> addWidget(hsb,1,0);
connect(hsb,TQT_SIGNAL(valueChanged(int)),TQT_SLOT(handleHSb(int)));
txtarea -> installEventFilter(this);
@@ -104,7 +104,7 @@ QextScintillaBase::QextScintillaBase(TQWidget *parent,const char *name,WFlags f)
lexersLinked = TRUE;
}
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
if (cb -> supportsSelection())
connect(cb,TQT_SIGNAL(selectionChanged()),TQT_SLOT(handleSelection()));
@@ -329,7 +329,7 @@ void QextScintillaBase::mousePress(TQMouseEvent *me)
case MidButton:
{
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
if (cb -> supportsSelection())
{
@@ -488,7 +488,7 @@ void QextScintillaBase::keyPressEvent(TQKeyEvent *ke)
// key.
if (ke -> text().length() == 1)
{
- if ((key = ke -> text()[0].unicode()) >= 0x80)
+ if ((key = ke -> text()[0].tqunicode()) >= 0x80)
key = 0;
}
else
@@ -563,12 +563,12 @@ void QextScintillaBase::handleHSb(int val)
// Return the current prefered size.
-TQSize QextScintillaBase::sizeHint() const
+TQSize QextScintillaBase::tqsizeHint() const
{
int height = sci -> vs.lineHeight * sci -> pdoc -> LinesTotal();
if (sci -> horizontalScrollBarVisible)
- height += hsb -> sizeHint().height();
+ height += hsb -> tqsizeHint().height();
return TQSize(sci -> scrollWidth,height);
}
@@ -577,6 +577,6 @@ TQSize QextScintillaBase::sizeHint() const
// Handle the selection changing.
void QextScintillaBase::handleSelection()
{
- if (!TQApplication::clipboard() -> ownsSelection())
+ if (!TQApplication::tqclipboard() -> ownsSelection())
sci -> UnclaimSelection();
}
diff --git a/qt/qextscintillabase.h b/qt/qextscintillabase.h
index 1e5a792..d4e73ba 100644
--- a/qt/qextscintillabase.h
+++ b/qt/qextscintillabase.h
@@ -2243,7 +2243,7 @@ public:
}
//! Returns the recommended size of the widget.
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
//! Returns the viewport widget. This is the widget that actually
//! contains the text.
diff --git a/qt/qextscintillalexer.cpp b/qt/qextscintillalexer.cpp
index 20a1c22..327206f 100644
--- a/qt/qextscintillalexer.cpp
+++ b/qt/qextscintillalexer.cpp
@@ -339,12 +339,12 @@ bool QextScintillaLexer::writeSettings(TQSettings &qs,const char *prefix) const
f = font(i);
fdesc += f.family();
- fdesc += fmt.arg(f.pointSize());
+ fdesc += fmt.tqarg(f.pointSize());
// The casts are for Borland.
- fdesc += fmt.arg((int)f.bold());
- fdesc += fmt.arg((int)f.italic());
- fdesc += fmt.arg((int)f.underline());
+ fdesc += fmt.tqarg((int)f.bold());
+ fdesc += fmt.tqarg((int)f.italic());
+ fdesc += fmt.tqarg((int)f.underline());
if (!qs.writeEntry(key + "font",fdesc,','))
rc = FALSE;
diff --git a/qt/qextscintillalexercss.cpp b/qt/qextscintillalexercss.cpp
index 6983202..ff15caa 100644
--- a/qt/qextscintillalexercss.cpp
+++ b/qt/qextscintillalexercss.cpp
@@ -199,16 +199,16 @@ const char *QextScintillaLexerCSS::keywords(int set) const
"border-top-style border-right-style "
"border-bottom-style border-left-style border-style "
"top right bottom left position z-index direction "
- "unicode-bidi min-width max-width min-height "
+ "tqunicode-bidi min-width max-width min-height "
"max-height overflow clip visibility content quotes "
"counter-reset counter-increment marker-offset size "
"marks page-break-before page-break-after "
"page-break-inside page orphans widows font-stretch "
- "font-size-adjust unicode-range units-per-em src "
+ "font-size-adjust tqunicode-range units-per-em src "
"panose-1 stemv stemh slope cap-height x-height "
"ascent descent widths bbox definition-src baseline "
"centerline mathline topline text-shadow "
- "caption-side table-layout border-collapse "
+ "caption-side table-tqlayout border-collapse "
"border-spacing empty-cells speak-header cursor "
"outline outline-width outline-style outline-color "
"volume speak pause-before pause-after pause "
diff --git a/qt/qextscintillalexerhtml.cpp b/qt/qextscintillalexerhtml.cpp
index 2da5f01..5013ff9 100644
--- a/qt/qextscintillalexerhtml.cpp
+++ b/qt/qextscintillalexerhtml.cpp
@@ -474,7 +474,7 @@ const char *QextScintillaLexerHTML::keywords(int set) const
"onselect onsubmit onunload "
"profile prompt "
"readonly rel rev rows rowspan rules "
- "scheme scope selected shape size span src standby "
+ "scheme scope selected tqshape size span src standby "
"start style summary "
"tabindex target text title topmargin type "
"usemap "
diff --git a/qt/qextscintillalexeridl.cpp b/qt/qextscintillalexeridl.cpp
index 51c8eb7..ceba60c 100644
--- a/qt/qextscintillalexeridl.cpp
+++ b/qt/qextscintillalexeridl.cpp
@@ -84,7 +84,7 @@ const char *QextScintillaLexerIDL::keywords(int set) const
"object odl oleautomation optimize optional out out_of_line "
"pipe pointer_default pragma properties propget propput "
"propputref ptr public range readonly ref represent_as "
- "requestedit restricted retval shape short signed size_is "
+ "requestedit restricted retval tqshape short signed size_is "
"small source strict_context_handle string struct switch "
"switch_is switch_type transmit_as typedef uidefault union "
"unique unsigned user_marshal usesgetlasterror uuid v1_enum "
diff --git a/qt/qextscintillalexertex.cpp b/qt/qextscintillalexertex.cpp
index 912b2a2..aa21e80 100644
--- a/qt/qextscintillalexertex.cpp
+++ b/qt/qextscintillalexertex.cpp
@@ -137,7 +137,7 @@ const char *QextScintillaLexerTeX::keywords(int set) const
"overwithdelims pagedepth pagefilllstretch "
"pagefillstretch pagefilstretch pagegoal pageshrink "
"pagestretch pagetotal par parfillskip parindent "
- "parshape parskip patterns pausing penalty "
+ "partqshape parskip patterns pausing penalty "
"postdisplaypenalty predisplaypenalty predisplaysize "
"pretolerance prevdepth prevgraf radical raise read "
"relax relpenalty right righthyphenmin rightskip "
diff --git a/qt/qextscintillaprinter.h b/qt/qextscintillaprinter.h
index a938c1a..3478b91 100644
--- a/qt/qextscintillaprinter.h
+++ b/qt/qextscintillaprinter.h
@@ -38,7 +38,7 @@ class QextScintillaBase;
//! \brief The QextScintillaPrinter class is a sub-class of the TQt TQPrinter
//! class that is able to print the text of a Scintilla document.
//!
-//! The class can be further sub-classed to alter to layout of the text, adding
+//! The class can be further sub-classed to alter to tqlayout of the text, adding
//! headers and footers for example.
class TQEXTSCINTILLA_EXPORT QextScintillaPrinter : public TQPrinter
{
diff --git a/src/AutoComplete.cpp b/src/AutoComplete.cpp
index 753adca..daa5fbb 100755
--- a/src/AutoComplete.cpp
+++ b/src/AutoComplete.cpp
@@ -45,11 +45,11 @@ bool AutoComplete::Active() {
void AutoComplete::Start(Window &parent, int ctrlID,
int position, Point location, int startLen_,
- int lineHeight, bool unicodeMode) {
+ int lineHeight, bool tqunicodeMode) {
if (active) {
Cancel();
}
- lb->Create(parent, ctrlID, location, lineHeight, unicodeMode);
+ lb->Create(parent, ctrlID, location, lineHeight, tqunicodeMode);
lb->Clear();
active = true;
startLen = startLen_;
diff --git a/src/AutoComplete.h b/src/AutoComplete.h
index 10577ca..8fd84c8 100755
--- a/src/AutoComplete.h
+++ b/src/AutoComplete.h
@@ -36,7 +36,7 @@ public:
/// Display the auto completion list positioned to be near a character position
void Start(Window &parent, int ctrlID, int position, Point location,
- int startLen_, int lineHeight, bool unicodeMode);
+ int startLen_, int lineHeight, bool tqunicodeMode);
/// The stop chars are characters which, when typed, cause the auto completion list to disappear
void SetStopChars(const char *stopChars_);
diff --git a/src/CallTip.cpp b/src/CallTip.cpp
index f4bc5f8..2de8eae 100755
--- a/src/CallTip.cpp
+++ b/src/CallTip.cpp
@@ -214,7 +214,7 @@ void CallTip::PaintCT(Surface *surfaceWindow) {
surfaceWindow->FillRectangle(rcClient, colourBG.allocated);
- offsetMain = insetX; // initial alignment assuming no arrows
+ offsetMain = insetX; // initial tqalignment assuming no arrows
PaintContents(surfaceWindow, true);
// Draw a raised border around the edges of the window
diff --git a/src/CallTip.h b/src/CallTip.h
index 9848a10..1fd38c3 100755
--- a/src/CallTip.h
+++ b/src/CallTip.h
@@ -18,7 +18,7 @@ class CallTip {
PRectangle rectUp; // rectangle of last up angle in the tip
PRectangle rectDown; // rectangle of last down arrow in the tip
int lineHeight; // vertical line spacing
- int offsetMain; // The alignment point of the call tip
+ int offsetMain; // The tqalignment point of the call tip
int tabSize; // Tab size in pixels, <=0 no TAB expand
bool useStyleCallTip; // if true, STYLE_CALLTIP should be used
diff --git a/src/Editor.cpp b/src/Editor.cpp
index 055f5dc..1abb78a 100755
--- a/src/Editor.cpp
+++ b/src/Editor.cpp
@@ -346,7 +346,7 @@ Editor::Editor() {
hasFocus = false;
hideSelection = false;
inOverstrike = false;
- errorStatus = 0;
+ errortqStatus = 0;
mouseDownCaptures = true;
bufferedDraw = true;
@@ -1949,7 +1949,7 @@ void Editor::LayoutLine(int line, Surface *surface, ViewStyle &vstyle, LineLayou
// See if chars, styles, indicators, are all the same
bool allSame = true;
const int styleMask = pdoc->stylingBitsMask;
- // Check base line layout
+ // Check base line tqlayout
char styleByte = 0;
int numCharsInLine = 0;
while (numCharsInLine < lineLength) {
@@ -1997,7 +1997,7 @@ void Editor::LayoutLine(int line, Surface *surface, ViewStyle &vstyle, LineLayou
char styleByte = 0;
int styleMask = pdoc->stylingBitsMask;
ll->styleBitsSet = 0;
- // Fill base line layout
+ // Fill base line tqlayout
for (int charInDoc = posLineStart; charInDoc < posLineEnd; charInDoc++) {
char chDoc = pdoc->CharAt(charInDoc);
styleByte = pdoc->StyleAt(charInDoc);
@@ -2815,7 +2815,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
startLineToWrap = -1;
if (WrapLines(false, startLineToWrap)) {
// The wrapping process has changed the height of some lines so
- // abandon this paint for a complete repaint.
+ // abandon this paint for a complete tqrepaint.
if (AbandonPaint()) {
return;
}
@@ -2892,7 +2892,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
//ElapsedTime et;
if (lineDoc != lineDocPrevious) {
ll.Set(0);
- // For rectangular selection this accesses the layout cache so should be after layout returned.
+ // For rectangular selection this accesses the tqlayout cache so should be after tqlayout returned.
lineIterator.SetAt(lineDoc);
ll.Set(RetrieveLineLayout(lineDoc));
LayoutLine(lineDoc, surface, vs, ll, wrapWidth);
@@ -2930,7 +2930,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
DrawLine(surface, vs, lineDoc, visibleLine, xStart, rcLine, ll, subLine);
//durPaint += et.Duration(true);
- // Restore the previous styles for the brace highlights in case layout is in cache.
+ // Restore the previous styles for the brace highlights in case tqlayout is in cache.
ll->RestoreBracesHighlight(rangeLine, braces);
bool expanded = cs.GetExpanded(lineDoc);
@@ -3372,7 +3372,7 @@ void Editor::AddCharUTF(char *s, unsigned int len, bool treatAsDBCS) {
// characters representing themselves.
} else {
// Unroll 1 to 3 byte UTF-8 sequences. See reference data at:
- // http://www.cl.cam.ac.uk/~mgk25/unicode.html
+ // http://www.cl.cam.ac.uk/~mgk25/tqunicode.html
// http://www.cl.cam.ac.uk/~mgk25/ucs/examples/UTF-8-test.txt
if (byte < 0xE0) {
int byte2 = static_cast<unsigned char>(s[1]);
@@ -3809,7 +3809,7 @@ void Editor::NotifyModified(Document*, DocModification mh, void *) {
}
//Platform::DebugPrintf("** %x Doc Changed\n", this);
- // TODO: could invalidate from mh.startModification to end of screen
+ // TODO: could tqinvalidate from mh.startModification to end of screen
//InvalidateRange(mh.position, mh.position + mh.length);
if (paintState == notPainting && !CanDeferToLastStep(mh)) {
Redraw();
@@ -5217,7 +5217,7 @@ void Editor::SetHotSpotRange(Point *pt) {
int hsStart_ = pdoc->ExtendStyleRange(pos, -1, vs.hotspotSingleLine);
int hsEnd_ = pdoc->ExtendStyleRange(pos, 1, vs.hotspotSingleLine);
- // Only invalidate the range if the hotspot range has changed...
+ // Only tqinvalidate the range if the hotspot range has changed...
if (hsStart_ != hsStart || hsEnd_ != hsEnd) {
if (hsStart != -1) {
InvalidateRange(hsStart, hsEnd);
@@ -7210,11 +7210,11 @@ sptr_t Editor::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam) {
return hasFocus;
case SCI_SETSTATUS:
- errorStatus = wParam;
+ errortqStatus = wParam;
break;
case SCI_GETSTATUS:
- return errorStatus;
+ return errortqStatus;
case SCI_SETMOUSEDOWNCAPTURES:
mouseDownCaptures = wParam != 0;
diff --git a/src/Editor.h b/src/Editor.h
index 2ce166d..7dca342 100755
--- a/src/Editor.h
+++ b/src/Editor.h
@@ -204,7 +204,7 @@ protected: // ScintillaBase subclass needs access to much of Editor
bool hasFocus;
bool hideSelection;
bool inOverstrike;
- int errorStatus;
+ int errortqStatus;
bool mouseDownCaptures;
/** In bufferedDraw mode, graphics operations are drawn to a pixmap and then copied to
diff --git a/src/LineMarker.cpp b/src/LineMarker.cpp
index 6ded13c..2af78b5 100755
--- a/src/LineMarker.cpp
+++ b/src/LineMarker.cpp
@@ -68,7 +68,7 @@ void LineMarker::Draw(Surface *surface, PRectangle &rcWhole, Font &fontForCharac
pxpm->Draw(surface, rcWhole);
return;
}
- // Restrict most shapes a bit
+ // Restrict most tqshapes a bit
PRectangle rc = rcWhole;
rc.top++;
rc.bottom--;
diff --git a/qt/SciListBox.cpp b/qt/SciListBox.cpp
index f873d7c..ef2475b 100644
--- a/qt/SciListBox.cpp
+++ b/qt/SciListBox.cpp
@@ -98,7 +98,7 @@ void ListBoxX::Create(Window &parent,int,Point,int,bool)
void ListBoxX::SetAverageCharWidth(int)
{
// We rely on TQListBox::sizeHint() for the size of the list box rather
// than make calculations based on the average character width and the
// number of visible rows.
}
@@ -121,7 +121,7 @@ PRectangle ListBoxX::GetDesiredRect()
if (slb)
{
- TQSize sh = slb -> sizeHint();
+ TQSize sh = slb -> tqsizeHint();
rc.right = sh.width();
rc.bottom = sh.height();
@@ -98,7 +98,7 @@ void ListBoxX::Create(Window &parent,int,Point,int,bool)
void ListBoxX::SetAverageCharWidth(int)
{
- // We rely on TQListBox::sizeHint() for the size of the list box rather
+ // We rely on TQListBox::tqsizeHint() for the size of the list box rather
// than make calculations based on the average character width and the
// number of visible rows.
diff --git a/qt/qextscintilla.cpp b/qt/qextscintilla.cpp
index d586e21..4b33791 100644
--- a/qt/qextscintilla.cpp
+++ b/qt/qextscintilla.cpp
@@ -1036,7 +1036,7 @@ void QextScintilla::foldClick(int lineClick,int bstate)
{
if (bstate & ShiftButton)
{
// Ensure all children are visible.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
}
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
{
if (SendScintilla(SCI_GETFOLDEXPANDED,lineClick))
{
// Contract this line and all its children.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,0L);
foldExpand(lineClick,FALSE,TRUE,0,levelClick);
}
else
{
// Expand this line and all its children.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
}
@@ -1119,7 +1119,7 @@ void QextScintilla::foldExpand(int &line,bool doExpand,bool force,
// Fully expand (if there is any line currently folded) all text. Otherwise,
// fold all text. This is mostly taken from SciTE.
-void QextScintilla::foldAll(bool children)
+void QextScintilla::foldAll(bool tqchildren)
{
recolor();
@@ -1142,7 +1142,7 @@ void QextScintilla::foldAll(bool children)
if (!(level & SC_FOLDLEVELHEADERFLAG))
continue;
- if (children ||
+ if (tqchildren ||
(SC_FOLDLEVELBASE == (level & SC_FOLDLEVELNUMBERMASK)))
{
if (expanding)
@@ -1036,7 +1036,7 @@ void QextScintilla::foldClick(int lineClick,int bstate)
if (bstate & ShiftButton)
{
- // Ensure all children are visible.
+ // Ensure all tqchildren are visible.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
if (SendScintilla(SCI_GETFOLDEXPANDED,lineClick))
{
- // Contract this line and all its children.
+ // Contract this line and all its tqchildren.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,0L);
foldExpand(lineClick,FALSE,TRUE,0,levelClick);
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
else
{
- // Expand this line and all its children.
+ // Expand this line and all its tqchildren.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
diff --git a/qt/qextscintilla.h b/qt/qextscintilla.h
index 331ebad..c34c88d 100644
--- a/qt/qextscintilla.h
+++ b/qt/qextscintilla.h
@@ -920,10 +920,10 @@ public slots:
//! If any lines are currently folded then they are all unfolded.
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
//! pressed. If \a children is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.
- virtual void foldAll(bool children = FALSE);
+ virtual void foldAll(bool tqchildren = FALSE);
//! If the line \a line is folded then it is unfolded. Otherwise it is
//! folded. This has the same effect as clicking in the fold margin.
@@ -920,10 +920,10 @@ public slots:
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
- //! pressed. If \a children is not set (the default) then only the top
+ //! pressed. If \a tqchildren is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.